# Esta linha é vital para que outros projetos Django possam importar sua AppConfig
default_app_config = 'django_minha_lib.apps.MinhaLibConfig'

# Defina a versão aqui (boa prática)
__version__ = '0.1.0'


from django.db import models
from django.utils.translation import gettext_lazy as _

class ItemRegistrado(models.Model):
    nome = models.CharField(max_length=100, verbose_name=_("Nome do Item"))
    criado_em = models.DateTimeField(auto_now_add=True)

    class Meta:
        verbose_name = _("Item Registrado")
        verbose_name_plural = _("Itens Registrados")
        ordering = ['criado_em']

    def __str__(self):
        return self.nome

def soma_um_e_dois():
    print("Calculando a soma de 1 + 2...")
    return 1 + 2



from django.apps import AppConfig
from django.utils.translation import gettext_lazy as _

class MinhaLibConfig(AppConfig):
    # O nome curto para a configuração (deve ser o nome do diretório)
    name = 'django_minha_lib'

    # O nome que aparece no painel de administração (admin)
    verbose_name = _('Minha Biblioteca Reutilizável')

    def ready(self):
        # Aqui você pode colocar lógica que deve ser executada quando o Django carrega o app.
        pass



from django.urls import path
from .views import PaginaInicialView

app_name = 'minha_lib'  # Nome do namespace da lib

urlpatterns = [
    # A URL será acessada como: /lib-path/
    path('', PaginaInicialView.as_view(), name='pagina_inicial'),
]



import time

from django import template

# Crie uma instância da biblioteca de templates
register = template.Library()


# Use o decorador simple_tag para registrar a função como uma template tag
@register.simple_tag
def show_today_timestamp():
    """
    Retorna o timestamp Unix atual (segundos desde a época).
    """
    # time.time() retorna o timestamp como um float
    timestamp = int(time.time())

    # mark_safe é opcional aqui, mas é uma boa prática se a saída fosse HTML puro
    return str(timestamp)


# --- Exemplo de como você faria se a tag precisasse de argumentos ---
@register.simple_tag
def saudacao(nome):
    """Retorna uma saudação personalizada."""
    return f"Olá, {nome}!"



from django.shortcuts import render
from django.views import View


class PaginaInicialView(View):
    def get(self, request):
        context = {
            'url_pypi': 'https://pypi.org/project/django-minha-lib/',
        }
        # O Django procurará por 'django_minha_lib/pagina_inicial.html'
        return render(request, 'django_minha_lib/pagina_inicial.html', context)
